#!/usr/bin/env python

from matplotlib import pyplot
import random


def plotMatrix(tuplesDict, labelsList):
    # list of string labels for rows/columns and
    # data in dictionary of tuples of these labels (row_label,col_label)
    
    # Map text labels to index used on plot
    # this is convenient if you want to reorganize the display order
    # just update the labelsList order.
    labelNameToIndex = {}
    for i,lab in enumerate(labelsList):
        labelNameToIndex[lab] = i

    # number of rows and columns
    numLabels = len(labelsList)

    #create a list of data points
    xyz = []
    for t in tuplesDict:
        x = labelNameToIndex[t[1]]
        # y values are reversed so output oriented the way I
        # think about matrices (0,0) in upper left.
        y = numLabels -1 - labelNameToIndex[t[0]]
        
        # extract value and color
        (z,c) = tuplesDict[t]

        xyz.append( (x,y,z,c))

    for x,y,z,c in xyz:
        pyplot.scatter([x],[y], s= [z], color = c, alpha = 0.4)

    tickLocations = range(numLabels)
    pyplot.xticks(tickLocations, labelsList, rotation = 90)
    # reverse the labels for y axis to match the data
    pyplot.yticks(tickLocations, labelsList[::-1]) 
    # set the axis 1 beyond the data so it looks good.
    pyplot.axis([-1, numLabels, -1, numLabels])


# Demonstrate how to use this matrix plot function
# with some lovely fake data.
random.seed()
game_freq = {}
rps = ['rock','paper','scissors']
winningCombos = [('paper','rock'),
                 ('rock','scissors'),
                 ('scissors','paper')]

for zia in rps:
    for josh in rps:
        t = (zia, josh) #tuple to identify this data point
        # determine color based on winner's gender
        if zia == josh:
            color = 'black' # a tie!
        elif t in winningCombos:
            color = 'red' # zia wins
        else:
            color = 'blue' # josh wins
            
        # add a random data point to the matrix
        game_freq[t] = (random.randint(50,1500), color)

# Random data maybe not so good for testing
# Let's add a data point to show how much Zia rocks.
game_freq[('rock','paper')] = (10000,'blue') 

# plot the data and axis labels
plotMatrix(game_freq, rps)

# plot other labels and save plot to a file.
outputFileName = 'Zia_vs_Josh_RPS.png'
pyplot.title("Zia and Josh play Rock Paper Scissors")
pyplot.ylabel("Zia")
pyplot.xlabel("Josh")
F= pyplot.gcf()
F.set_size_inches(5,5)
print 'saving... ', outputFileName
F.savefig(outputFileName, bbox_inches = 'tight', pad_inches = 0.02)
